LdIcons class

collection of icons that ship with liquid

Constructors

LdIcons()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

add → const IconData
arrow_double_left → const IconData
arrow_down → const IconData
arrow_left → const IconData
arrow_right → const IconData
arrow_up → const IconData
arrow_up_n_down → const IconData
atom → const IconData
attention → const IconData
audio → const IconData
baby → const IconData
bacteria_microscope_view → const IconData
basket → const IconData
battery → const IconData
battery_empty → const IconData
battery_full → const IconData
battery_half → const IconData
battery_low → const IconData
beaker → const IconData
beard → const IconData
bell → const IconData
big_cross → const IconData
bin → const IconData
bitcoin → const IconData
bottle → const IconData
bulb → const IconData
burger → const IconData
burger_menu → const IconData
cabriolet → const IconData
calendar → const IconData
camcorder → const IconData
camera → const IconData
car → const IconData
cards → const IconData
chat → const IconData
checkmark → const IconData
choir → const IconData
clip → const IconData
clock → const IconData
cloud → const IconData
cloud_download → const IconData
cloud_upload → const IconData
coffe → const IconData
control → const IconData
conversation → const IconData
copy → const IconData
cost_center → const IconData
coupon → const IconData
credit_card → const IconData
cross → const IconData
dashboard → const IconData
data_storage → const IconData
dna → const IconData
documents → const IconData
documents_storage → const IconData
dollar → const IconData
donut → const IconData
dot → const IconData
download → const IconData
eco → const IconData
education → const IconData
electric_car → const IconData
energy → const IconData
euro → const IconData
external_export → const IconData
fast_forward → const IconData
favorite → const IconData
files → const IconData
filter → const IconData
finance → const IconData
first_aid → const IconData
flask → const IconData
football → const IconData
gamepad → const IconData
half_dot → const IconData
half_star → const IconData
house → const IconData
initial_m → const IconData
jpeg → const IconData
keys → const IconData
laptop → const IconData
laptop_mobile → const IconData
layer → const IconData
list → const IconData
location → const IconData
lock_save → const IconData
logistic → const IconData
m_card → const IconData
magnifier → const IconData
mail → const IconData
matryoshka → const IconData
medical_file → const IconData
medicine → const IconData
meetup → const IconData
mic → const IconData
microscope → const IconData
mobile → const IconData
money → const IconData
monitor → const IconData
monkey → const IconData
option → const IconData
pause → const IconData
pdf → const IconData
pen → const IconData
phone → const IconData
pill → const IconData
pipette → const IconData
pisces → const IconData
placeholder → const IconData
plane → const IconData
plant → const IconData
play → const IconData
pound → const IconData
pretzel → const IconData
print → const IconData
pulse → const IconData
puzzle → const IconData
refresh → const IconData
repost → const IconData
rewind → const IconData
rocket → const IconData
san_francisco → const IconData
satelite → const IconData
savings → const IconData
scientific_paper → const IconData
scissors → const IconData
secure_conncetion → const IconData
security → const IconData
settings → const IconData
share → const IconData
shield → const IconData
sock → const IconData
solar_power → const IconData
star → const IconData
stethoscope → const IconData
stop → const IconData
syringe → const IconData
tea_pot → const IconData
test_tube → const IconData
three_d → const IconData
truck → const IconData
upload → const IconData
user → const IconData
ux → const IconData
virus → const IconData
visibity → const IconData
vr → const IconData
watch → const IconData
website → const IconData
wi_fi → const IconData
world → const IconData
youtube → const IconData
zip → const IconData